@@ -3,9 +3,9 @@ Main interface for codeguru-reviewer service type definitions.
 
 Usage::
 
-    from mypy_boto3.codeguru_reviewer.type_defs import RepositoryAssociationTypeDef
+    from mypy_boto3.codeguru_reviewer.type_defs import CodeCommitRepositoryTypeDef
 
-    data: RepositoryAssociationTypeDef = {...}
+    data: CodeCommitRepositoryTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,32 +22,130 @@ else:
 
 
 __all__ = (
-    "RepositoryAssociationTypeDef",
-    "AssociateRepositoryResponseTypeDef",
-    "MetricsTypeDef",
-    "CommitDiffSourceCodeTypeTypeDef",
-    "SourceCodeTypeTypeDef",
+    "CodeCommitRepositoryTypeDef",
+    "CodeReviewSummaryTypeDef",
     "CodeReviewTypeDef",
-    "DescribeCodeReviewResponseTypeDef",
+    "CommitDiffSourceCodeTypeTypeDef",
+    "MetricsSummaryTypeDef",
+    "MetricsTypeDef",
+    "RecommendationFeedbackSummaryTypeDef",
     "RecommendationFeedbackTypeDef",
+    "RecommendationSummaryTypeDef",
+    "RepositoryAssociationSummaryTypeDef",
+    "RepositoryAssociationTypeDef",
+    "SourceCodeTypeTypeDef",
+    "ThirdPartySourceRepositoryTypeDef",
+    "AssociateRepositoryResponseTypeDef",
+    "DescribeCodeReviewResponseTypeDef",
     "DescribeRecommendationFeedbackResponseTypeDef",
     "DescribeRepositoryAssociationResponseTypeDef",
     "DisassociateRepositoryResponseTypeDef",
-    "MetricsSummaryTypeDef",
-    "CodeReviewSummaryTypeDef",
     "ListCodeReviewsResponseTypeDef",
-    "RecommendationFeedbackSummaryTypeDef",
     "ListRecommendationFeedbackResponseTypeDef",
-    "RecommendationSummaryTypeDef",
     "ListRecommendationsResponseTypeDef",
-    "RepositoryAssociationSummaryTypeDef",
     "ListRepositoryAssociationsResponseTypeDef",
     "PaginatorConfigTypeDef",
-    "CodeCommitRepositoryTypeDef",
-    "ThirdPartySourceRepositoryTypeDef",
     "RepositoryTypeDef",
 )
 
+CodeCommitRepositoryTypeDef = TypedDict("CodeCommitRepositoryTypeDef", {"Name": str})
+
+CodeReviewSummaryTypeDef = TypedDict(
+    "CodeReviewSummaryTypeDef",
+    {
+        "Name": str,
+        "CodeReviewArn": str,
+        "RepositoryName": str,
+        "Owner": str,
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
+        "State": Literal["Completed", "Pending", "Failed", "Deleting"],
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
+        "Type": Literal["PullRequest"],
+        "PullRequestId": str,
+        "MetricsSummary": "MetricsSummaryTypeDef",
+    },
+    total=False,
+)
+
+CodeReviewTypeDef = TypedDict(
+    "CodeReviewTypeDef",
+    {
+        "Name": str,
+        "CodeReviewArn": str,
+        "RepositoryName": str,
+        "Owner": str,
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
+        "State": Literal["Completed", "Pending", "Failed", "Deleting"],
+        "StateReason": str,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
+        "Type": Literal["PullRequest"],
+        "PullRequestId": str,
+        "SourceCodeType": "SourceCodeTypeTypeDef",
+        "Metrics": "MetricsTypeDef",
+    },
+    total=False,
+)
+
+CommitDiffSourceCodeTypeTypeDef = TypedDict(
+    "CommitDiffSourceCodeTypeTypeDef", {"SourceCommit": str, "DestinationCommit": str}, total=False
+)
+
+MetricsSummaryTypeDef = TypedDict(
+    "MetricsSummaryTypeDef", {"MeteredLinesOfCodeCount": int, "FindingsCount": int}, total=False
+)
+
+MetricsTypeDef = TypedDict(
+    "MetricsTypeDef", {"MeteredLinesOfCodeCount": int, "FindingsCount": int}, total=False
+)
+
+RecommendationFeedbackSummaryTypeDef = TypedDict(
+    "RecommendationFeedbackSummaryTypeDef",
+    {"RecommendationId": str, "Reactions": List[Literal["ThumbsUp", "ThumbsDown"]], "UserId": str},
+    total=False,
+)
+
+RecommendationFeedbackTypeDef = TypedDict(
+    "RecommendationFeedbackTypeDef",
+    {
+        "CodeReviewArn": str,
+        "RecommendationId": str,
+        "Reactions": List[Literal["ThumbsUp", "ThumbsDown"]],
+        "UserId": str,
+        "CreatedTimeStamp": datetime,
+        "LastUpdatedTimeStamp": datetime,
+    },
+    total=False,
+)
+
+RecommendationSummaryTypeDef = TypedDict(
+    "RecommendationSummaryTypeDef",
+    {
+        "FilePath": str,
+        "RecommendationId": str,
+        "StartLine": int,
+        "EndLine": int,
+        "Description": str,
+    },
+    total=False,
+)
+
+RepositoryAssociationSummaryTypeDef = TypedDict(
+    "RepositoryAssociationSummaryTypeDef",
+    {
+        "AssociationArn": str,
+        "ConnectionArn": str,
+        "LastUpdatedTimeStamp": datetime,
+        "AssociationId": str,
+        "Name": str,
+        "Owner": str,
+        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
+        "State": Literal["Associated", "Associating", "Failed", "Disassociating"],
+    },
+    total=False,
+)
+
 RepositoryAssociationTypeDef = TypedDict(
     "RepositoryAssociationTypeDef",
     {
@@ -65,158 +163,69 @@ RepositoryAssociationTypeDef = TypedDict(
     total=False,
 )
 
+SourceCodeTypeTypeDef = TypedDict(
+    "SourceCodeTypeTypeDef", {"CommitDiff": "CommitDiffSourceCodeTypeTypeDef"}, total=False
+)
+
+ThirdPartySourceRepositoryTypeDef = TypedDict(
+    "ThirdPartySourceRepositoryTypeDef", {"Name": str, "ConnectionArn": str, "Owner": str}
+)
+
 AssociateRepositoryResponseTypeDef = TypedDict(
     "AssociateRepositoryResponseTypeDef",
-    {"RepositoryAssociation": RepositoryAssociationTypeDef},
-    total=False,
-)
-
-MetricsTypeDef = TypedDict(
-    "MetricsTypeDef", {"MeteredLinesOfCodeCount": int, "FindingsCount": int}, total=False
-)
-
-CommitDiffSourceCodeTypeTypeDef = TypedDict(
-    "CommitDiffSourceCodeTypeTypeDef", {"SourceCommit": str, "DestinationCommit": str}, total=False
-)
-
-SourceCodeTypeTypeDef = TypedDict(
-    "SourceCodeTypeTypeDef", {"CommitDiff": CommitDiffSourceCodeTypeTypeDef}, total=False
-)
-
-CodeReviewTypeDef = TypedDict(
-    "CodeReviewTypeDef",
-    {
-        "Name": str,
-        "CodeReviewArn": str,
-        "RepositoryName": str,
-        "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
-        "State": Literal["Completed", "Pending", "Failed", "Deleting"],
-        "StateReason": str,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-        "Type": Literal["PullRequest"],
-        "PullRequestId": str,
-        "SourceCodeType": SourceCodeTypeTypeDef,
-        "Metrics": MetricsTypeDef,
-    },
+    {"RepositoryAssociation": "RepositoryAssociationTypeDef"},
     total=False,
 )
 
 DescribeCodeReviewResponseTypeDef = TypedDict(
-    "DescribeCodeReviewResponseTypeDef", {"CodeReview": CodeReviewTypeDef}, total=False
-)
-
-RecommendationFeedbackTypeDef = TypedDict(
-    "RecommendationFeedbackTypeDef",
-    {
-        "CodeReviewArn": str,
-        "RecommendationId": str,
-        "Reactions": List[Literal["ThumbsUp", "ThumbsDown"]],
-        "UserId": str,
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-    },
-    total=False,
+    "DescribeCodeReviewResponseTypeDef", {"CodeReview": "CodeReviewTypeDef"}, total=False
 )
 
 DescribeRecommendationFeedbackResponseTypeDef = TypedDict(
     "DescribeRecommendationFeedbackResponseTypeDef",
-    {"RecommendationFeedback": RecommendationFeedbackTypeDef},
+    {"RecommendationFeedback": "RecommendationFeedbackTypeDef"},
     total=False,
 )
 
 DescribeRepositoryAssociationResponseTypeDef = TypedDict(
     "DescribeRepositoryAssociationResponseTypeDef",
-    {"RepositoryAssociation": RepositoryAssociationTypeDef},
+    {"RepositoryAssociation": "RepositoryAssociationTypeDef"},
     total=False,
 )
 
 DisassociateRepositoryResponseTypeDef = TypedDict(
     "DisassociateRepositoryResponseTypeDef",
-    {"RepositoryAssociation": RepositoryAssociationTypeDef},
-    total=False,
-)
-
-MetricsSummaryTypeDef = TypedDict(
-    "MetricsSummaryTypeDef", {"MeteredLinesOfCodeCount": int, "FindingsCount": int}, total=False
-)
-
-CodeReviewSummaryTypeDef = TypedDict(
-    "CodeReviewSummaryTypeDef",
-    {
-        "Name": str,
-        "CodeReviewArn": str,
-        "RepositoryName": str,
-        "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
-        "State": Literal["Completed", "Pending", "Failed", "Deleting"],
-        "CreatedTimeStamp": datetime,
-        "LastUpdatedTimeStamp": datetime,
-        "Type": Literal["PullRequest"],
-        "PullRequestId": str,
-        "MetricsSummary": MetricsSummaryTypeDef,
-    },
+    {"RepositoryAssociation": "RepositoryAssociationTypeDef"},
     total=False,
 )
 
 ListCodeReviewsResponseTypeDef = TypedDict(
     "ListCodeReviewsResponseTypeDef",
-    {"CodeReviewSummaries": List[CodeReviewSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-RecommendationFeedbackSummaryTypeDef = TypedDict(
-    "RecommendationFeedbackSummaryTypeDef",
-    {"RecommendationId": str, "Reactions": List[Literal["ThumbsUp", "ThumbsDown"]], "UserId": str},
+    {"CodeReviewSummaries": List["CodeReviewSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListRecommendationFeedbackResponseTypeDef = TypedDict(
     "ListRecommendationFeedbackResponseTypeDef",
     {
-        "RecommendationFeedbackSummaries": List[RecommendationFeedbackSummaryTypeDef],
+        "RecommendationFeedbackSummaries": List["RecommendationFeedbackSummaryTypeDef"],
         "NextToken": str,
     },
     total=False,
 )
 
-RecommendationSummaryTypeDef = TypedDict(
-    "RecommendationSummaryTypeDef",
-    {
-        "FilePath": str,
-        "RecommendationId": str,
-        "StartLine": int,
-        "EndLine": int,
-        "Description": str,
-    },
-    total=False,
-)
-
 ListRecommendationsResponseTypeDef = TypedDict(
     "ListRecommendationsResponseTypeDef",
-    {"RecommendationSummaries": List[RecommendationSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-RepositoryAssociationSummaryTypeDef = TypedDict(
-    "RepositoryAssociationSummaryTypeDef",
-    {
-        "AssociationArn": str,
-        "ConnectionArn": str,
-        "LastUpdatedTimeStamp": datetime,
-        "AssociationId": str,
-        "Name": str,
-        "Owner": str,
-        "ProviderType": Literal["CodeCommit", "GitHub", "Bitbucket"],
-        "State": Literal["Associated", "Associating", "Failed", "Disassociating"],
-    },
+    {"RecommendationSummaries": List["RecommendationSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListRepositoryAssociationsResponseTypeDef = TypedDict(
     "ListRepositoryAssociationsResponseTypeDef",
-    {"RepositoryAssociationSummaries": List[RepositoryAssociationSummaryTypeDef], "NextToken": str},
+    {
+        "RepositoryAssociationSummaries": List["RepositoryAssociationSummaryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
@@ -224,14 +233,8 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
-CodeCommitRepositoryTypeDef = TypedDict("CodeCommitRepositoryTypeDef", {"Name": str})
-
-ThirdPartySourceRepositoryTypeDef = TypedDict(
-    "ThirdPartySourceRepositoryTypeDef", {"Name": str, "ConnectionArn": str, "Owner": str}
-)
-
 RepositoryTypeDef = TypedDict(
     "RepositoryTypeDef",
-    {"CodeCommit": CodeCommitRepositoryTypeDef, "Bitbucket": ThirdPartySourceRepositoryTypeDef},
+    {"CodeCommit": "CodeCommitRepositoryTypeDef", "Bitbucket": "ThirdPartySourceRepositoryTypeDef"},
     total=False,
 )
